#include <stdio.h>
#include <math.h>

typedef struct { double x,y; } point;
typedef struct { double a,b,c; } line;

line make_line( point A, point B) {

	line m;
	m.a=B.y-A.y;
	m.b=A.x-B.x;
	m.c=A.y*(B.x-A.x)-A.x*(B.y-A.y);

	return m;
}

void print_line( line m ) {
	printf("%.2lf*x%+.2lf*y%+.2lf=0\n",m.a,m.b,m.c);
}

void print_line_in_segments( line m ) {

	double div_x=-m.c/m.a;
	double div_y=-m.c/m.b;
	char sign_x=' ';
	if(div_x<0) sign_x='-';
	char sign_y='+';
	if(div_y<0) sign_y='-';

	printf("%cx/%.2lf%cy/%.2lf=1\n",sign_x,fabs(div_x),sign_y,fabs(div_y));
}

point centre_of_gravity(line m) {

	point p;
	p.x=-m.c/m.a/3.; // центр тяжести с координатами 1/3 от стороны треугольника
	p.y=-m.c/m.b/3.;
	return p;
}

double distance(point p, line m){
	return fabs(m.a*p.x+m.b*p.y+m.c)/sqrt(m.a*m.a+m.b*m.b);
}

void main() {

	point P={1,3};

	// тут нужно поставить координаты точек в соответствии с вариантом 3
	// у меня просто три пары произвольных точек
	point A1={-1,-4},     B1={-3.1,-0.9};
//	point A1={1,4},     B1={3.1,0.9};
	point A2={0.5,2.5}, B2={1.5,1.1};
	point A3={-0.7,14}, B3={7,-1.4};

	line m1=make_line(A1,B1);
	line m2=make_line(A2,B2);
	line m3=make_line(A3,B3);

	point centre1=centre_of_gravity(m1);
	point centre2=centre_of_gravity(m2);
	point centre3=centre_of_gravity(m3);


	printf("Equations of line\n");
	print_line(m1);
	print_line(m2);
	print_line(m3);

	printf("\n(a) Equations of line in segments\n");
	print_line_in_segments(m1);
	print_line_in_segments(m2);
	print_line_in_segments(m3);


	printf("\n(b) Distance from point (1,3) to line\n");
	printf("%lf\n",distance(P,m1));
	printf("%lf\n",distance(P,m2));
	printf("%lf\n",distance(P,m3));

	printf("\n(c) Coordinates of centre of gravity\n");
	printf("{%lf,%lf}\n",centre1.x,centre1.y);
	printf("{%lf,%lf}\n",centre2.x,centre2.y);
	printf("{%lf,%lf}\n",centre3.x,centre3.y);
}

